@@ -3,8 +3,8 @@ setx.MI <- function(object, fn = list(numeric = mean, ordered =
                     cond = FALSE, counter = NULL, ...) {
   M <- length(object)
   dta <- NULL
+  obj <- object[[1]]
   if (!cond) {# unconditional predition
-    obj <- object[[1]]
     for (i in 1:M) {
       if(is.null(data))
         tmp <- as.data.frame(eval(getcall(obj)$data,
@@ -13,20 +13,22 @@ setx.MI <- function(object, fn = list(numeric = mean, ordered =
         tmp <- data[[i]]
       dta <- rbind(dta, tmp)
     }
-    X <- NextMethod("setx", object = object[[1]], fn = fn, data = dta, cond = FALSE,
-                    counter = NULL, ...)
-    #X <- setx(object[[1]], fn = fn, data = dta, cond = FALSE,
-    #         counter = NULL, dots)
+    #X <- NextMethod("setx", object = object[[1]], fn = fn, data = dta, cond = FALSE,
+    #                counter = NULL, ...)
+    X <- setx(object[[1]], fn = fn, data = dta, cond = FALSE,
+             counter = NULL, ...)
     class(X) <- c("setx.MI", "setx", "data.frame")
   }
   else { # conditional prediction
     X <- list()
     if (is.null(data))
       data <- eval(getcall(obj)$data, sys.parent())
-    for (i in 1:M)
+    for (i in 1:M){
       X[[i]] <- setx(object[[i]], fn = NULL, data = data[[i]], cond = TRUE,
                               counter = counter, ...)
-    class(X) <- c("setx.MI", "cond", "data.frame")
+	class(X[[i]]) <- c("cond", "data.frame")
+	}
+    class(X) <- c("setx.MI", "setx.cond", "cond")
   }
   return(X)
 }
